==> fetch.php?media=releases%3A1.03b.zip: Properties/AssemblyInfo.cs <==
﻿using System.Reflection;
using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
using System.Resources;

// Obecné informace o sestavení jsou řízeny přes následující 
// sadu atributů. Změnou hodnot těchto atributů se upraví informace
// přidružené k sestavení.
[assembly: AssemblyTitle("Packet Mapper")]
[assembly: AssemblyDescription("Anonmapping Trace Files")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("Jiří Havelka")]
[assembly: AssemblyProduct("Packet Mapper")]
[assembly: AssemblyCopyright("free GNU")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]

// Nastavení atributu ComVisible na hodnotu False udělá typy v tomto sestavení neviditelné 
// pro komponenty modelu COM.  Jestliže potřebujete přistupovat k typům v tomto sestavení z 
// modelu COM, nastavte atribut ComVisible daného typu na hodnotu True.
[assembly: ComVisible(false)]

// Následující identifikátor GUID slouží k identifikaci knihovny typů, jestliže je projekt vystaven objektům modelu COM
[assembly: Guid("c1cdb4e9-985f-445f-ae06-08455725b6cf")]

// Informace o verzi sestavení se skládá z následujících čtyř hodnot:
//
//      Hlavní verze
//      Podverze 
//      Číslo sestavení
//      Revize
//
// Lze zadat všechny hodnoty nebo nechat hodnoty Čísel Sestavení a Revize ve výchozím nastavení 
// použitím '*' jak je ukázáno dále:
// [assembly: AssemblyVersion("1.0.*")]
[assembly: AssemblyVersion("0.1.0.1")]
[assembly: AssemblyFileVersion("0.1.0.1")]
[assembly: NeutralResourcesLanguageAttribute("en")]

==> fetch.php?media=releases%3A1.04.zip: Properties/AssemblyInfo.cs <==
﻿using System.Reflection;
using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
using System.Resources;

// Obecné informace o sestavení jsou řízeny přes následující 
// sadu atributů. Změnou hodnot těchto atributů se upraví informace
// přidružené k sestavení.
[assembly: AssemblyTitle("Packet Mapper")]
[assembly: AssemblyDescription("Network Trace Anonymization")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("Jiří Havelka")]
[assembly: AssemblyProduct("Packet Mapper")]
[assembly: AssemblyCopyright("public GNU")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]

// Nastavení atributu ComVisible na hodnotu False udělá typy v tomto sestavení neviditelné 
// pro komponenty modelu COM.  Jestliže potřebujete přistupovat k typům v tomto sestavení z 
// modelu COM, nastavte atribut ComVisible daného typu na hodnotu True.
[assembly: ComVisible(false)]

// Následující identifikátor GUID slouží k identifikaci knihovny typů, jestliže je projekt vystaven objektům modelu COM
[assembly: Guid("c1cdb4e9-985f-445f-ae06-08455725b6cf")]

// Informace o verzi sestavení se skládá z následujících čtyř hodnot:
//
//      Hlavní verze
//      Podverze 
//      Číslo sestavení
//      Revize
//
// Lze zadat všechny hodnoty nebo nechat hodnoty Čísel Sestavení a Revize ve výchozím nastavení 
// použitím '*' jak je ukázáno dále:
// [assembly: AssemblyVersion("1.0.*")]
[assembly: AssemblyVersion("1.4.0.0")]
[assembly: AssemblyFileVersion("1.4.0.0")]
[assembly: NeutralResourcesLanguageAttribute("en")]
